pub struct ScaleFlags(pub(crate) u32);Expand description
Flags that define how scaling and hinting is applied.
Tuple Fields
0: u32Implementations
Sourceimpl ScaleFlags
impl ScaleFlags
Sourcepub const HORIZONTAL_SNAP: Self
pub const HORIZONTAL_SNAP: Self
Stem width snapping.
Sourcepub const VERTICAL_SNAP: Self
pub const VERTICAL_SNAP: Self
Stem height snapping.
Sourcepub const STEM_ADJUST: Self
pub const STEM_ADJUST: Self
Stem width/height adjustment.
Sourcepub const NO_HORIZONTAL: Self
pub const NO_HORIZONTAL: Self
Disable horizontal hinting.
Sourcepub const NO_VERTICAL: Self
pub const NO_VERTICAL: Self
Disable vertical hinting.
Sourcepub const NO_ADVANCE: Self
pub const NO_ADVANCE: Self
Disable advance hinting.
Sourceimpl ScaleFlags
impl ScaleFlags
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Creates new flags, truncating the given bits to valid values.
Sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Returns true if self contains all flags in other.
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self contains any flags in other.