pub struct UnscaledStyleMetrics {
pub(crate) class_ix: u16,
pub digits_have_same_width: bool,
pub(crate) axes: [UnscaledAxisMetrics; 2],
}Expand description
Unscaled metrics for a single style and script.
Fields
class_ix: u16Index of style class.
digits_have_same_width: boolMonospaced digits?
axes: [UnscaledAxisMetrics; 2]Per-dimension unscaled metrics.
Implementations
Sourceimpl UnscaledStyleMetrics
impl UnscaledStyleMetrics
Sourcepub fn new(
font: &FontRef<'_>,
coords: &[NormalizedCoord],
style: &StyleClass,
) -> Self
pub fn new( font: &FontRef<'_>, coords: &[NormalizedCoord], style: &StyleClass, ) -> Self
Creates a set of metrics for the given font, normalized coordinates and style class.
Sourcepub fn scale(&self, scale: Scale) -> ScaledStyleMetrics
pub fn scale(&self, scale: Scale) -> ScaledStyleMetrics
Applies the given scale to this set of style metrics.
Sourceimpl UnscaledStyleMetrics
impl UnscaledStyleMetrics
Sourcepub fn style_class(&self) -> &'static StyleClass
pub fn style_class(&self) -> &'static StyleClass
Returns the associated style class.
Sourcepub fn horizontal_metrics(&self) -> &UnscaledAxisMetrics
pub fn horizontal_metrics(&self) -> &UnscaledAxisMetrics
Returns unscaled metrics for the horizontal axis.
Sourcepub fn vertical_metrics(&self) -> &UnscaledAxisMetrics
pub fn vertical_metrics(&self) -> &UnscaledAxisMetrics
Returns unscaled metrics for the vertical axis.